# Norman Core SDK

A Python Low Level SDK for Norman, providing access to the entire Norman Api.

## Package Structure

- `norman_sdk/accounts/` – Account and authentication logic
- `norman_sdk/models/` – Model registration and retrieval
- `norman_sdk/invoke/` – Model invocation
- `norman_sdk/services/` – Low-level SDK, with services for each Norman API endpoint
- `norman_sdk/utils/` – Utility functions (I/O, hashing, etc.)
## Installation

```bash
pip install .
```

## Usage
...

## Test
```
# low level test:
pytest # -v = verbose, -s = show prints 
```
